interface TagFormatDefinition {}

interface TagCategoryDefinitions {
  [key: string]: TagFormatDefinition;
}

interface TagActivityDefinitions {
  [key: string]: TagCategoryDefinitions;
}

interface TagDefinitions {
  [key: string]: TagActivityDefinitions;
}

interface TagStatus {
  definition?: TagFormatDefinition;
  highlighted: boolean;
}

export const getTagStatus = <TagStatus>(
  tag: string,
  definitions: TagDefinitions,
  selectedKey: string,
  highlightedKey: string
) => {
  const defaultStatus = {
    highlighted: false,
  };
  const activityDefinitions = definitions[selectedKey];
  if (!activityDefinitions) {
    return defaultStatus;
  }

  const highlightedDefinitions = activityDefinitions[highlightedKey];

  if (!!highlightedDefinitions) {
    const definition = highlightedDefinitions[tag];
    if (!!definition) {
      return { definition, highlighted: true };
    }
  }

  for (const category of Object.keys(activityDefinitions)) {
    if (category !== highlightedKey) {
      const categoryDefinitions = activityDefinitions[category];
      const definition = categoryDefinitions[tag];
      if (!!definition) {
        return { definition, highlighted: false };
      }
    }
  }

  return defaultStatus;
};
